4Suite API Documentation: Ft.Lib.DistExt.Py2Exe

4Suite™ API Documentation

# ► Module Ft.Lib.DistExt.Py2Exe

Classes: py2exe

## Classes

class py2exe(py2exe.build_exe.py2exe)
  Command class replacement for py2exe's that adds Ft extension module's hidden imports and package data.

  ### Methods

  copy_extensions(self, extensions)
    Overridden to also copy any hidden package data files to the target directory.
  parse_mf_results(self, mf)
    Overridden to add our "hidden" imports.
  plat_finalize(self, modules, py_files, extensions, dlls)
    Overridden to also find any package data files.